import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { dom } from '@alfalab/core-components-shared/modern';
import { useFocus } from '@alfalab/hooks';
import { CheckmarkCompactMIcon } from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

const styles = {"component":"checkbox__component_jbpgs","start":"checkbox__start_jbpgs","center":"checkbox__center_jbpgs","addons":"checkbox__addons_jbpgs","block":"checkbox__block_jbpgs","box":"checkbox__box_jbpgs","checkedIcon":"checkbox__checkedIcon_jbpgs","s":"checkbox__s_jbpgs","disabled":"checkbox__disabled_jbpgs","checked":"checkbox__checked_jbpgs","indeterminate":"checkbox__indeterminate_jbpgs","indeterminateLine":"checkbox__indeterminateLine_jbpgs","label":"checkbox__label_jbpgs","hint":"checkbox__hint_jbpgs","focused":"checkbox__focused_jbpgs","content":"checkbox__content_jbpgs","errorMessage":"checkbox__errorMessage_jbpgs"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', boxClassName, contentClassName, align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, hiddenInput = false, labelProps, error, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    const errorMessage = typeof error === 'boolean' ? '' : error;
    return (React.createElement("label", { ...labelProps, className: cn(styles.component, styles[size], styles[align], className, labelProps?.className, {
            [styles.disabled]: disabled || inactive,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref, labelProps?.ref]) },
        !hiddenInput && (React.createElement("input", { type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId, ...restProps })),
        React.createElement("span", { className: cn(styles.box, boxClassName) },
            checked && React.createElement(CheckmarkCompactMIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && (
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        React.createElement("span", { className: styles.addons, onClick: dom.preventDefault }, addons))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
